
penman.surface
==============

.. automodule:: penman.surface

   Epigraphical Markers
   --------------------

   .. autoclass:: AlignmentMarker
      :show-inheritance:
      :members:

   .. autoclass:: Alignment
      :show-inheritance:

   .. autoclass:: RoleAlignment
      :show-inheritance:

   Module Functions
   ----------------

   .. autofunction:: alignments
   .. autofunction:: role_alignments
